@@ -41,8 +41,6 @@ SDL_Sound *wav_expl2 = 0; /* (cluster)bomb explosion */
 SDL_Sound *wav_expl3 = 0; /* tank explosion */
 SDL_Sound *wav_cannon1 = 0; /* grenade autocannon */
 SDL_Sound *wav_cannon2 = 0;
-SDL_Sound *wav_scream1 = 0;
-SDL_Sound *wav_scream2 = 0; /* human screams */
 SDL_Sound *wav_click = 0;
 SDL_Sound *wav_highlight = 0;
 
@@ -68,10 +66,10 @@ static void data_free_cursor( SDL_Cursor **cursor )
 
 static SDL_Cursor* data_create_cursor( int width, int height, int hot_x, int hot_y, char *source )
 {
-	char *mask = 0, *data = 0;
+	unsigned char *mask = 0, *data = 0;
 	SDL_Cursor *cursor = 0;
 	int i, j, k;
-	char data_byte, mask_byte;
+	unsigned char data_byte, mask_byte;
 	int pot;
 
 	/* meaning of char from source: b : black, w: white, ' ':transparent */
@@ -220,7 +218,7 @@ void data_load()
 	background = data_create_image( screen->w, screen->h ); 
 	img_cursors = data_load_image( "cursors.bmp" );
 	SET_CKEY( img_cursors, 0x0 );
-	cursor_w = img_cursors->w / 4;
+	cursor_w = img_cursors->w / CURSOR_COUNT;
 	img_gun = data_load_image( "gun.bmp" );
 	SDL_LockSurface( img_gun );
 	SET_CKEY( img_gun, *(Uint16*)(img_gun->pixels) );
@@ -241,8 +239,6 @@ void data_load()
 	wav_expl3 = data_load_sound( "expl3.wav" );
 	wav_cannon1 = data_load_sound( "autocannon.wav" );
 	wav_cannon2 = data_load_sound( "gunfire.wav" );
-	wav_scream1 = data_load_sound( "scream1.wav" );
-	wav_scream2 = data_load_sound( "scream2.wav" );
 	wav_click = data_load_sound( "click.wav" );
 	wav_highlight = data_load_sound( "highlight.wav" );
 #endif
@@ -296,8 +292,6 @@ void data_delete()
 	data_free_sound( &wav_expl2 );
 	data_free_sound( &wav_expl3 );
 	data_free_sound( &wav_cannon1 );
-	data_free_sound( &wav_scream1 );
-	data_free_sound( &wav_scream2 );
 	data_free_sound( &wav_click );
 	data_free_sound( &wav_highlight );
 	printf( "%i sounds deleted\n", wav_count );
@@ -305,4 +299,3 @@ void data_delete()
 
 	data_free_cursor( &cr_empty );
 }
-
