@@ -107,9 +107,10 @@ enum {
 	CURSOR_ARROW,
 	CURSOR_CROSSHAIR,
 	CURSOR_WAIT,
-	CURSOR_RELOAD
+	CURSOR_RELOAD,
+	CURSOR_DISABLED,
+	CURSOR_COUNT = 5
 };
 #define SET_CURSOR(type) cursor_x_offset=type*cursor_w
 
 #endif
-
