@@ -57,6 +57,7 @@ Vector gun_img_offset = { -9, -20, 0 };
 int player_score = 0;
 int player_ammo = 0;
 char player_name[20] = "Michael"; /* is updated when entering highscore */
+
 int game_start = 0, game_end = 0; /* time in global secs when game started and has to end */
 
 int timer_blink_delay = 0; /* timer starts to blink when time runs out */
@@ -70,6 +71,16 @@ enum {
 };
 int state = STATE_MENU; /* state of game */
 
+/* Lets try to get name from environment */
+static void set_player_name_from_env() 
+{
+	char * user_name = getenv("USER");
+	if (user_name!=NULL)
+	{
+		strncpy(player_name, user_name, 19);
+	}
+};
+
 static void fade_screen( int type, int time )
 {
 	SDL_Surface *buffer = 0;
@@ -208,6 +219,7 @@ static void draw_ammo()
 	}
 }
 
+extern BField bfield;
 /* draw cursor centered at x,y */
 static void draw_cursor( SDL_Surface *dest, int x, int y )
 {
@@ -216,6 +228,11 @@ static void draw_cursor( SDL_Surface *dest, int x, int y )
 	drect.w = srect.w = cursor_w;
 	drect.h = srect.h = img_cursors->h;
 	srect.x = cursor_x_offset; srect.y = 0;
+	/* XXX: within gun strip, gun cannot be fired; to indicate this use
+	 * disabled cursor instead of current selection. (bad hack, state
+	 * should be properly set somewhere) */
+	if ( x < STRIP_OFFSET && !bfield.demo )
+		srect.x = CURSOR_DISABLED * cursor_w;
 	drect.x = x - (cursor_w>>1); drect.y = y - (img_cursors->h>>1);
 	SDL_BlitSurface( img_cursors, &srect, dest, &drect );
 }
@@ -231,7 +248,7 @@ static void draw_logo_centered( SDL_Surface *dest, int y )
 
 	SDL_BlitSurface( img_logo, 0, dest, &drect );
 
-	SDL_WriteText( ft_copyright, dest, 4, 454, "(C) 2003 Michael Speck" );
+	SDL_WriteText( ft_copyright, dest, 4, 454, "(C) 2003-2010 Michael Speck" );
 	SDL_WriteTextRight( ft_copyright, dest, 636, 454, "http://lgames.sf.net" );
 }
 
@@ -244,8 +261,8 @@ static void draw_help( SDL_Surface *dest )
 	SDL_BlitSurface( img_black, 0, dest, 0 );
 	
 	/* objective */
-	LINE(10,"Your objective is to destroy as many targets as" );
-	LINE(30,"possible within 3 minutes." );
+	LINE(10,"Your objective is to destroy as many dummy" );
+	LINE(30,"targets as possible within 3 minutes." );
 	
 	/* icons and points */
 	SDL_WriteText( ft_help, dest, x,target_y, "Target Scores:" );
@@ -541,7 +558,7 @@ int main( int argc, char **argv )
   char c;
   
   printf( "BARRAGE v%s\n", VERSION );
-  printf( "Copyright 2003-2005 Michael Speck (http://lgames.sf.net)\n" );
+  printf( "Copyright 2003-2010 Michael Speck (http://lgames.sf.net)\n" );
   printf( "Released under Gnu GPL\n---\n" );
 
   while ( ( c = getopt( argc, argv, "d:ws" ) ) != -1 )
@@ -556,6 +573,8 @@ int main( int argc, char **argv )
   printf("main loop delay: %d ms\n",delay);
 	
   srand( time(0) );
+
+  set_player_name_from_env();
 	
   if ( SDL_Init( SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_AUDIO ) < 0 ) {
     printf( "%s\n", SDL_GetError() );
@@ -599,4 +618,3 @@ int main( int argc, char **argv )
 	
   return (0);
 }
-
